@@ -3,22 +3,12 @@
  *
  * Authors: Jorn Baayen <jorn@openedhand.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
+#include <config.h>
+
 #include <libgupnp-av/gupnp-search-criteria-parser.h>
 #include <stdlib.h>
 
@@ -36,10 +26,6 @@ main (G_GNUC_UNUSED int argc, G_GNUC_UNUSED char **argv)
         GError *error;
         guint i;
 
-#if !GLIB_CHECK_VERSION (2, 35, 0)
-        g_type_init ();
-#endif
-
         parser = gupnp_search_criteria_parser_new ();
 
         for (i = 0; i < G_N_ELEMENTS (searches); i++) {
